from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x08\x00\x55\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x9b\x08\x00\x00\x00\x00\x00\x18\x3d\x13\x3d\x51\x90\xd0\x01\x2a\x9f\xf5\x18\xf6\xb7\xd2\x5c\x18\x00\x00\x00\x00\x00\x00\x00\x00\xe3\x0d\x8d\x94\x39\x51\xce\xf7\xf0\x60\x8c\x3c\x67\x16\x07\x0b\x76\xc7\xfc\xc2\x24\x24\x1f\xec\x26\x3c\x42\x56\x76\xfe\x26\x01\x47\x3f\x2b\x3e\xb6\x95\x87\xd5\x00\xf3\xbc\x73\x92\x52\x14\x33\x71\x6f\xbe\x7e\x9a\x76\x2d\x5d\x26\x83\x6e\xf2\x97\x89\x15\x6a\x6f\x26\x1e\xc1\x8d\x95\xc1\xd6\x42\xbe\xe1\x4e\x46\x26\xb8\x7c\x09\x04\x15\x96\x0e\x52\xc9\x03\x8b\xf1\x24\x1e\x14\xbc\xcc\x20\x69\x19\xce\x21\x7a\x39\x50\xa2\xd7\xc6\x9b\xf2\x4a\x8d\x44\x8b\x81\xc8\x9f\x70\x33\xfa\xec\x76\x7c\xbc\x6d\xf9\xc4\xbb\x0d\xcc\x7a\xe3\x57\x63\xdc\x08\x09\xf7\x10\xc2\x23\xef\x3e\xc9\x45\xe4\xe3\xc2\xa9\xa3\xac\xd9\x7e\xcc\xb9\x95\xf1\x45\x6a\xe8\x18\xa7\x9b\xd3\x49\x29\xbd\xc0\xc4\x35\xda\xa7\x90\x9f\x13\xd0\x7b\x79\xbf\x43\xbf\xc2\xba\x6a\xb8\xce\xae\x3a\x7c\x17\x54\xee\xf8\x30\xee\x4d\x79\xc5\x65\xb2\xe9\x18\x56\x92\xde\x81\x82\x8c\x46\xe8\xc5\x13\x46\x42\xa1\xe5\x14\x17\x8c\x7e\xa5\x59\x60\x24\x69\xed\x6f\x9a\x7c\xe0\x29\xcb\x3b\xea\x99\xb1\x7a\x0f\x03\x0a\xc5\x92\xe8\xb5\x6b\x18\x73\x71\x4b\xc6\x52\x8e\x45\x26\xf2\x64\x1b\xe7\x95\x16\xea\x9e\x46\x60\x84\x7a\xc2\x7a\xfb\x38\x42\x05\x77\x62\x20\xf8\x6d\x17\x3e\x40\x3c\xac\x90\x05\x55\x39\x92\x49\x31\x5c\xa5\xd6\xe2\x2b\xf0\x61\x6e\xef\x64\xc1\x62\xe5\x21\x99\xbf\x32\x41\x77\x5a\x63\x43\x75\x0c\x98\x2d\x0b\x3a\x91\x04\x0b\xd3\xe7\x28\xc8\x7d\xa0\xcd\x30\xac\x71\x77\x4b\x41\xab\x97\xa2\xe3\xd0\xfe\xc6\x9f\x32\x38\x62\x7a\x19\xfe\x80\xa4\x68\x7a\x17\x91\xab\xb2\x11\x9e\x58\x20\x68\x66\x25\xa9\xf8\xd0\x43\x94\xc0\xc3\x25\xe8\xc5\x7f\x9f\x8a\xfe\x99\x1b\x1d\xcc\xa3\x14\xe6\xa0\xe5\x11\xff\xba\xb3\x82\xbf\xa9\x0d\x82\x42\x73\x03\xb5\xa9\x88\x25\x05\x2a\xe0\xeb\xf7\x73\xf9\xe3\x6f\x6f\x95\x63\xe3\x7d\xb3\x19\x26\xcf\xe6\x2c\xd0\x1a\xb2\xe4\x2a\xa8\x6d\xc1\x7e\x72\xe6\x06\xd3\xb0\x62\x2e\xfe\x53\xd5\xec\xd0\x8e\xd6\xbc\x03\x5e\x34\xc1\x5d\x47\x55\x2f\xdc\x24\x1f\x69\x11\x05\xd7\x2b\xa8\x8b\x64\x16\x63\xe0\x8d\x3a\x84\xe0\x55\xe5\xa6\xc5\xca\xb8\x09\xef\x9c\x78\xf9\xc2\xbd\x58\x10\x42\x1b\xc2\xd1\x31\x60\x41\x42\x42\xa8\xa2\xb9\x18\xbe\xf5\x61\x01\x3a\x1b\x55\xfa\xc4\x29\x7a\xf8\x69\x38\x0a\x87\x41\x51\x8e\x3b\xc1\x18\x78\xa7\xe1\xcc\xf7\x79\xb4\x5c\x9f\x64\x8a\x7c\x2a\x9a\x77\x8b\x38\x59\xde\x07\x01\x1c\x3f\xe7\x05\xdd\x36\xc9\x69\x43\x94\x0a\x39\xf2\x3e\x91\x1b\xc8\xfb\xd0\x8f\xe4\x0a\x13\x5b\x4c\xdd\x7b\x46\x73\x68\x83\x5f\x38\x43\xcb\x2b\xa2\x20\xe4\x64\x13\xad\x10\x63\x48\xdc\x52\x69\xaa\x43\x0e\x81\x14\x1a\x0e\xfa\x72\xf5\x1d\x46\x27\xae\xcb\x97\x1a\xba\x5c\x36\x85\xb0\xf1\x46\x09\xd7\x42\x98\x6d\x53\xd5\xa1\x63\x81\x83\x9e\x59\x85\xeb\xfa\x71\x32\xba\xb7\xfa\x0f\xe9\xf2\x8c\xee\x89\x65\x27\xbe\x75\xae\xd8\xe4\x27\xbb\x6a\x33\x68\x37\xeb\x4f\xc2\x3f\x7a\x53\x68\x1c\xd6\x6b\x83\x8f\x08\x70\x97\xec\x36\x10\x75\x62\x69\x01\x19\x5b\x1d\x8c\xd3\x1b\xac\x72\xc1\x21\x84\xd4\xe4\xd7\x9c\x0e\x68\x45\xe0\xed\x8d\x73\x40\xa0\xc3\xd9\x7a\xff\x77\xe6\x6f\x73\x48\x66\x81\xe6\xb5\x02\x26\x47\xea\x34\x78\xf6\x26\x94\xd5\xac\x84\x32\x5b\x95\xbd\x71\x65\x5f\x6e\xc1\x78\xdf\x56\x36\x11\x05\x8f\xb4\xc0\x09\x83\x33\x19\xf2\xec\x5c\x75\x6e\x55\x38\xa5\x42\x47\x2e\x5e\x11\x8f\x7b\x78\x69\x14\x9d\x8e\xd3\xe7\xff\x08\xad\x56\x05\xc7\xaa\xde\xa0\x49\x7a\x06\x8b\x28\x5e\xda\x1f\xf4\x0c\x99\x3c\xfb\xae\xfd\x85\xbc\x10\xa7\xb2\xdb\xd1\xc2\xb6\xe9\xcf\x11\xb7\x4a\x68\x79\xe1\x5b\xfc\x30\xaf\xdb\xa3\x1d\x15\xc8\x04\x2c\x03\xea\x21\x03\x7b\x00\x79\x10\x63\xca\xbe\xca\x41\x61\x1d\x44\x8f\x28\x5c\x6a\xc1\x07\x43\xe9\x64\x4a\xa1\x55\x26\xfe\x78\x3b\x0a\xc2\xab\x4e\x73\x37\x30\x30\x56\x0b\x4e\x56\x43\x7f\xf7\xcb\xf1\x30\x28\x1a\x39\x10\xcc\x75\x6f\x1e\xa8\x35\xba\x39\x99\x0e\x5a\x5e\x59\xa2\x37\x4b\x3d\x2b\xe4\x87\x96\xb0\xc2\xd3\xbb\x97\x89\x87\xd0\x60\x6e\x25\x5f\xfd\x2b\x28\xe7\xbe\x7f\x91\x9c\x9a\xc4\x19\xe0\xc1\x9a\x95\x08\x7f\xcc\xed\xb2\x33\x02\xfb\x90\x4e\xfa\x7f\x8e\xde\xc6\xce\x9a\x9f\x5f\x8e\xbf\xcd\x44\x47\xcf\x01\x59\x6e\x6b\x09\x32\xca\x03\x90\x7c\x73\xd3\xb1\x61\x12\xb0\x05\x37\x7a\x90\x68\xd2\xea\x47\x1c\x26\xa0\x30\x61\x6f\x19\x76\x1c\x68\x83\xc7\x5b\x21\xe8\x8e\xde\xf3\xa8\x8d\xff\x0f\x88\xfe\x9a\x2a\xb7\x64\x68\x93\x22\xf0\xc3\x5e\x12\xff\xa9\xda\x94\x0c\xf3\x5a\xc4\x5c\x65\xef\xa9\x93\x24\x3f\x2b\x9f\x1e\x48\x40\x23\x70\x94\x6f\x1a\x94\xbd\x4d\xdf\x09\x06\x99\xd6\x45\x58\x1a\x58\x7f\x3d\xa5\x03\x95\xa1\x93\x6c\xe7\xfb\x01\xe8\xd1\x2d\xb5\x2c\x6b\xe3\xfa\x06\xe6\x55\x4e\x41\xb2\x95\x8e\xbe\xef\xe4\xe4\xf7\x38\x27\xa7\x08\x7d\xaf\x21\x6f\x2b\x89\xb7\xdb\x00\x75\xe4\x02\x63\x0d\xea\xde\x97\x83\x61\x5c\xc3\x09\x1a\x11\xf6\xd9\x6b\xb5\x78\xa7\x3c\xf2\xba\xb8\xc7\xde\x28\x37\xad\x86\xa0\x32\x57\x0a\xa2\xcf\x61\x65\x17\xc6\x82\xa4\x55\x38\xe2\x55\x9e\x1b\xc2\x29\xd8\xea\x46\xc0\x31\x4f\x4f\x15\x9f\x15\x27\xd8\x14\xd7\x0f\xd2\xb7\x9a\x64\x88\x78\xd5\x70\xa3\xe9\xc5\xf9\x36\x02\x03\x5e\x9d\xe7\xc0\xd9\x93\x5b\x72\x77\x24\x10\x88\x54\x5e\x52\x96\x1f\xbc\x9e\xf9\xfc\xb0\x85\xba\x5f\x11\x76\x6b\xf7\x6d\x0f\x8b\xb1\x11\xa3\xac\x28\x8b\xce\x2c\xd4\x64\xb1\x33\xa2\x9b\xfa\x5c\xdb\x10\x4d\xb7\x7a\x8f\x10\x4a\xa5\x88\x42\x3c\x97\xb1\xf2\xfa\x8a\xd4\xfe\xd3\xfe\x56\x73\x13\x9f\xee\x5a\x72\x33\x43\xa9\x17\x25\x19\x1b\x1c\x6b\xd1\x47\xa6\xeb\xd3\x72\x2e\xc0\x52\xe3\x89\x47\xab\x8f\x55\xe6\xb7\x0b\xd2\xec\x64\x88\x6a\xc2\x37\xe0\x4b\xf1\x98\xb2\x11\x10\x20\x75\x68\xf6\xd6\xb9\xe8\xf4\x3e\x26\xf0\xac\x5f\x74\x80\xd2\xd2\xf7\x30\xfe\x0c\xfb\x33\xdd\x3f\xc5\x2a\x7e\x27\x98\x69\xdb\x79\x14\x22\xf6\x6b\x3d\x46\x33\xca\xa9\xbb\x62\xaa\x8c\xd1\xea\x83\x03\xaf\x7a\xd7\x28\x2e\x2e\x23\xec\x50\x96\xeb\x5f\x4e\x64\xdb\x72\xfe\xa7\x62\xd9\x67\x85\x0b\x06\xb5\xe1\xb9\xbe\xea\x9f\xf7\x79\xfa\xce\x32\x76\x99\x98\xc4\xb6\xe9\xde\x29\xba\xab\x19\x42\xb5\xa6\x73\x6c\x55\x1f\xdf\x8d\x28\xaf\x61\xb0\x53\xf6\xc4\x9d\x0c\xd1\x1e\x60\x25\x54\x2d\x04\x59\x6d\x41\x9e\xbe\xed\x97\x30\xc9\x75\x2f\xfc\xd0\xbb\x66\x57\x3d\x1b\x2a\xd6\x06\xf9\x4f\x6a\x3f\xdf\xf8\x87\x8c\x99\xa6\x62\x44\x91\x1b\x77\xa2\x03\x59\xb1\x75\xd3\x5b\x6c\x77\x70\xf7\x6b\x09\xb2\xad\x96\x96\xb7\x6b\x4a\x7f\x1a\x96\x6b\xcd\xe6\x22\x87\x8b\x4a\xa1\x1f\xe0\x6d\x83\xbb\x52\xa2\x42\x01\xf7\x82\x24\x4c\xa1\xb5\xd4\x8f\x61\x89\xd4\xdb\xd9\xe3\x84\xbf\xb3\x4b\x6d\xfd\xba\xf5\x7c\xc9\x22\x2f\xa7\x86\x5a\xd5\xf1\xea\x65\x62\x7e\xb0\x3a\xa4\x4d\x63\x8b\x31\x78\x8a\x06\x7a\x23\xc3\x53\xdf\x3c\x73\xc6\x15\x1e\xef\xf7\xad\xbb\x7b\x8f\xcf\x77\x67\xc7\x49\xb1\x5e\xe8\x56\xad\xe7\xe2\xe2\x71\xd3\xc7\x25\xd8\x7a\x88\x4c\xb6\x4b\xd7\xfd\x40\x26\x70\xf6\xe1\xbe\xd3\x6b\x9c\x53\x48\xe0\xba\xb3\xe3\x78\x73\x20\xfb\x9f\x02\xc6\x0f\xf1\xa6\x9e\xa5\x00\x38\x86\x54\x52\x96\x57\x0a\x05\x64\x09\xf5\x8d\x09\xd1\x50\xdc\xce\x55\xad\x9c\x42\x63\xbb\x65\x83\xd7\xbd\x7f\xa1\x3c\xa4\xe6\x5b\xa7\x47\xd0\xac\x6d\x61\xda\xf5\xf2\x07\x98\xa8\x9a\xc1\x0c\x1f\x42\xc0\x66\xf2\x00\xff\x4f\xd5\x48\xfd\xca\x76\x2f\xb8\xc1\xe3\xa5\x58\x17\x51\x97\xae\xf5\x0e\xbe\x28\x15\x6d\x7c\x62\x43\xb7\x8d\x53\x16\x5d\x8f\x1f\x21\x7b\xb3\x97\x2e\x18\x8d\x96\xad\x75\xc2\x02\x77\x45\x51\x6a\x2c\x42\xfd\x2c\x16\x58\xb3\xaf\x0c\xe4\xca\x77\x6f\x65\xf4\x42\x68\xd3\xdb\xcd\x6a\x8b\x5c\x05\x5f\x2c\x1c\xbc\x4b\x6a\x98\x65\x87\x30\x12\xf0\x80\x1a\xcc\x1a\x73\x8f\xb1\x89\xea\xf3\xaa\x52\xba\xa6\x9c\x8a\x5d\x97\xf4\x3f\xea\xd0\x07\x8b\x1a\x50\x27\xf0\xec\xb1\xbf\xde\xdd\x0e\x1e\xdc\x59\xab\xc0\x42\x5c\x87\x9b\x8e\xe7\x72\x37\xeb\x22\xe1\x1e\xec\x7e\xad\x10\x16\xef\x74\xae\xcd\x50\xc0\x74\x13\xe7\x63\xd0\x74\x96\x01\xe2\x24\x6d\x0d\xc5\xb4\x6e\xd4\x67\x59\xc5\xf8\x80\x8e\x73\xd9\x0d\xfc\x8f\x2f\xc7\x87\xe7\xe2\x52\xc8\x80\x99\x43\x52\xbf\x47\xc1\xd8\x9a\xd2\xdb\xa8\x89\x76\x2d\xd8\x4b\x4f\x67\xd2\xd1\x5d\x4f\xc0\x57\xa3\x26\xba\x04\xcd\x8f\x20\x6c\x5b\x35\xbd\x8e\x00\xd8\x72\x4d\x3c\x12\x08\x5b\x07\xda\x68\x26\xd0\x05\x69\x5c\x5b\x4e\xae\xce\x76\xcd\x07\xa0\x99\xf1\x1d\x9b\xef\x67\x4d\xba\xc8\x78\xf1\x5f\xfc\xbd\x4e\xca\xb0\xd7\xec\x81\x07\x64\x4e\x50\xde\xae\xf3\x15\x0a\x36\x7b\xe9\x88\x47\xe6\xcb\x7f\x10\x80\xac\x7d\x04\x36\xde\x89\x6b\x91\x1c\xa3\xf8\x6f\x0b\x31\xc3\xdd\xce\x3c\x57\x0b\xca\x5c\xda\x94\xeb\x95\xb4\x46\xeb\xf7\x72\x80\xc8\x78\x6d\x98\x33\x1e\xf2\x1f\x5f\x48\x7a\x32\xf1\x38\xb1\x39\x37\x30\x53\x1a\x26\x49\x75\x29\x40\xf8\xb8\xaf\xa3\xb0\xff\xc7\x28\xd7\x7b\x5e\x43\xa0\xe2\x60\x42\x61\xbe\xec\xfc\xe0\x56\x38\x3c\x6c\xfb\xb2\x2f\x59\x92\x69\x88\x7b\x1a\x47\x5a\x7a\x99\x0d\xaa\x26\x29\x11\x98\x6f\x1a\xcb\xb7\xa1\x43\xf0\x33\x70\xdc\xa5\x9d\x47\xcc\xde\xea\xdb\x34\x28\x09\x82\xf5\x9f\x01\x78\x2e\x46\x11\xb7\x3e\x4f\xab\xfd\x95\x5f\x8b\x73\xb1\x4d\xba\x6f\x2b\x96\x7d\x0f\x39\x6d\x28\x2f\xf7\x6d\xfc\xf6\x37\x72\xec\xd0\x7a\x37\xcd\xb9\x04\xfd\xe0\xc7\x25\xf2\xc3\x38\xe8\xf4\xd6\x76\xd3\xdb\x10\x27\x91\x39\xfc\x16\xab\x90\x8d\x59\xb3\x21\x66\xcd\x7b\xc5\x6d\x36\x89\xdf\x05\x31\x08\x2e\x99\xe3\xb2\xba\xc7\xa5\x7f\xf6\x42\x29\x7d\xea\x62\x62\x78\x3c\x69\xbc\x7d\x33\x7f\xdb\x2e\xef\xfb\x86\xb0\x9b\xc1\xb9\x08\xc0\x27\xe7\xe9\x44\xeb\x2b\x68\x5e\xbc\x14\x22\x2a\x17\x79\x2b\xc2\xc4\xc5\x96\xe8\x4f\x27\x4d\x52\x86\x67\x0b\x10\x6c\x3f\x2a\x42\xad\x1e\xeb\x9b\x42\xb4\xe3\xd0', 2)

# cleanup
del pyarmor_runtime

